@@ -1,5 +1,6 @@
-use hudsucker::{certificate_authority::RcgenAuthority, rustls::internal::pemfile, *};
+use hudsucker::{certificate_authority::RcgenAuthority, *};
 use log::*;
+use rustls_pemfile as pemfile;
 use std::net::SocketAddr;
 
 async fn shutdown_signal() {
@@ -14,12 +15,16 @@ async fn main() {
 
     let mut private_key_bytes: &[u8] = include_bytes!("ca/hudsucker.key");
     let mut ca_cert_bytes: &[u8] = include_bytes!("ca/hudsucker.pem");
-    let private_key = pemfile::pkcs8_private_keys(&mut private_key_bytes)
-        .expect("Failed to parse private key")
-        .remove(0);
-    let ca_cert = pemfile::certs(&mut ca_cert_bytes)
-        .expect("Failed to parse CA certificate")
-        .remove(0);
+    let private_key = rustls::PrivateKey(
+        pemfile::pkcs8_private_keys(&mut private_key_bytes)
+            .expect("Failed to parse private key")
+            .remove(0),
+    );
+    let ca_cert = rustls::Certificate(
+        pemfile::certs(&mut ca_cert_bytes)
+            .expect("Failed to parse CA certificate")
+            .remove(0),
+    );
 
     let ca = RcgenAuthority::new(private_key, ca_cert, 1_000)
         .expect("Failed to create Certificate Authority");
